@@ -18,7 +18,8 @@ class TestExpressionParser : public DUChainTestBase
 public:
     TestExpressionParser();
 
-private slots:
+private Q_SLOTS:
+    void newClass_data();
     void newClass();
     void newSelf();
     void newStatic();
@@ -32,12 +33,15 @@ private slots:
     void invalidTraitUse();
     void namespaceUseNameConflict();
     void globalFunction();
+    void globalFunctionCall_data();
+    void globalFunctionCall();
     void chainCall();
     void thisObject();
     void integralTypes();
     void newObject();
     void cast();
     void operations();
+    void findArg_data();
     void findArg();
     void array_data();
     void array();
@@ -53,6 +57,11 @@ private slots:
     void invalidVariadicFunction_data();
     void invalidVariadicFunction();
     void invalidArgumentUnpacking();
+    void closure_data();
+    void closure();
+    void closureUse_data();
+    void closureUse();
+    void closureInvalidUse();
 };
 
 }
